@@ -1,20 +1,39 @@
 package Email::Sender::Transport::Maildir;
-{
-  $Email::Sender::Transport::Maildir::VERSION = '1.300009'; # TRIAL
-}
+# ABSTRACT: deliver mail to a maildir on disk
+$Email::Sender::Transport::Maildir::VERSION = '1.300015'; # TRIAL
 use Moo;
 with 'Email::Sender::Transport';
-# ABSTRACT: deliver mail to a maildir on disk
 
 use Errno ();
 use Fcntl;
-use File::Path;
+use File::Path 2.06;
 use File::Spec;
 
 use Sys::Hostname;
 
 use MooX::Types::MooseLike::Base qw(Bool);
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This transport delivers into a maildir.  The maildir's location may be given as
+#pod the F<dir> argument to the constructor, and defaults to F<Maildir> in the
+#pod current directory (at the time of transport initialization).
+#pod
+#pod If the directory does not exist, it will be created.
+#pod
+#pod By default, three headers will be added:
+#pod
+#pod  * X-Email-Sender-From - the envelope sender
+#pod  * X-Email-Sender-To   - the envelope recipients (one header per rcpt)
+#pod  * Lines               - the number of lines in the body
+#pod
+#pod These can be controlled with the C<add_lines_header> and
+#pod C<add_envelope_headers> constructor arguments.
+#pod
+#pod The L<Email::Sender::Success> object returned on success has a C<filename>
+#pod method that returns the filename to which the message was delivered.
+#pod
+#pod =cut
 
 {
   package
@@ -80,7 +99,7 @@ sub _ensure_maildir_exists {
     next if -d $subdir;
 
     Email::Sender::Failure->throw("couldn't create $subdir: $!")
-      unless File::Path::mkpath($subdir);
+      unless File::Path::make_path($subdir) || -d $subdir;
   }
 }
 
@@ -155,13 +174,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
 
 =head1 VERSION
 
-version 1.300009
+version 1.300015
 
 =head1 DESCRIPTION
 
@@ -189,7 +210,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
