@@ -1,12 +1,23 @@
 package Email::Sender::Transport::Sendmail;
-{
-  $Email::Sender::Transport::Sendmail::VERSION = '1.300009'; # TRIAL
-}
-use Moo;
-use MooX::Types::MooseLike::Base qw(Str);
-with 'Email::Sender::Transport';
 # ABSTRACT: send mail via sendmail(1)
+$Email::Sender::Transport::Sendmail::VERSION = '1.300015'; # TRIAL
+use Moo;
+with 'Email::Sender::Transport';
 
+use MooX::Types::MooseLike::Base qw(Str);
+
+#pod =head2 DESCRIPTION
+#pod
+#pod This transport sends mail by piping it to the F<sendmail> command.  If the
+#pod location of the F<sendmail> command is not provided in the constructor (see
+#pod below) then the library will look for an executable file called F<sendmail> in
+#pod the path.
+#pod
+#pod To specify the location of sendmail:
+#pod
+#pod   my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
+#pod
+#pod =cut
 
 use File::Spec ();
 
@@ -58,8 +69,8 @@ sub _sendmail_pipe {
   my $prog = $self->sendmail;
 
   my ($first, @args) = $^O eq 'MSWin32'
-           ? qq(| "$prog" -f $envelope->{from} @{$envelope->{to}})
-           : (q{|-}, $prog, '-f', $envelope->{from}, '--', @{$envelope->{to}});
+           ? qq(| "$prog" -i -f $envelope->{from} @{$envelope->{to}})
+           : (q{|-}, $prog, '-i', '-f', $envelope->{from}, '--', @{$envelope->{to}});
 
   no warnings 'exec'; ## no critic
   my $pipe;
@@ -77,7 +88,7 @@ sub send_email {
   my $string = $email->as_string;
   $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
 
-  print $pipe $email->as_string
+  print $pipe $string
     or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
 
   close $pipe
@@ -93,13 +104,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 1.300009
+version 1.300015
 
 =head2 DESCRIPTION
 
@@ -118,7 +131,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
