@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Email::Sender::Util;
-{
-  $Email::Sender::Util::VERSION = '1.300009'; # TRIAL
-}
 # ABSTRACT: random stuff that makes Email::Sender go
-
+$Email::Sender::Util::VERSION = '1.300015'; # TRIAL
 use Email::Address;
 use Email::Sender::Failure;
 use Email::Sender::Failure::Permanent;
@@ -40,7 +37,23 @@ sub _sender_from_email {
 # now I don't want to deal with making a sane set of args. -- rjbs, 2008-12-09
 sub _failure {
   my ($self, $error, $smtp, @rest) = @_;
-  my $code = $smtp ? $smtp->code : undef;
+
+  my ($code, $message);
+  if ($smtp) {
+    $code = $smtp->code;
+    $message = $smtp->message;
+    $message = ! defined $message ? "(no SMTP error message)"
+             : ! length  $message ? "(empty SMTP error message)"
+             :                       $message;
+
+    $message = defined $error && length $error
+             ? "$error: $message"
+             : $message;
+  } else {
+    $message = $error;
+    $message = "(no error given)" unless defined $message;
+    $message = "(empty error string)" unless length $message;
+  }
 
   my $error_class = ! $code       ? 'Email::Sender::Failure'
                   : $code =~ /^4/ ? 'Email::Sender::Failure::Temporary'
@@ -48,9 +61,7 @@ sub _failure {
                   :                 'Email::Sender::Failure';
 
   $error_class->new({
-    message => $smtp
-               ? ($error ? ("$error: " . $smtp->message) : $smtp->message)
-               : $error,
+    message => $message,
     code    => $code,
     @rest,
   });
@@ -73,13 +84,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Util - random stuff that makes Email::Sender go
 
 =head1 VERSION
 
-version 1.300009
+version 1.300015
 
 =head1 AUTHOR
 
@@ -87,7 +100,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
